@@ -17,42 +17,48 @@ class ForumLogin:
     def __init__(self, name: str, username: str, password: str):
         self.name = name
         self.logged_in = False
-        self.lock = False
         self.username = username
         self.password = password
 
     async def login(self, session: ScrapeSession, url: URL, quiet: bool):
         """Handles forum logging in"""
-        if self.username and self.password:
-            if not self.lock:
-                while True:
-                    if self.logged_in:
-                        return
-                    self.lock = True
-                    domain = URL("https://" + url.host) / "login"
-                    text = await session.get_text(domain)
-                    soup = BeautifulSoup(text, 'html.parser')
-
-                    inputs = soup.select('form input')
-                    data = {
-                        elem['name']: elem['value']
-                        for elem in inputs
-                        if elem.get('name') and elem.get('value')
-                    }
-                    data.update({"login": self.username, "password": self.password,
-                                 "_xfRedirect": str(domain)})
-                    await session.post_data_no_resp(domain / "login", data=data)
-                    text = await session.get_text(domain)
-                    if "You are already logged in" in text:
-                        self.logged_in = True
-                        self.lock = False
-                        return
-                    else:
-                        self.lock = False
-                        raise FailedLoginFailure()
-        else:
+        if not self.username or not self.password:
             await log(f"[red]Login wasn't provided for {self.name}[/red]", quiet=quiet)
             raise FailedLoginFailure()
+        attempt = 0
+        while True:
+            try:
+                if self.logged_in:
+                    return
+                if attempt == 5:
+                    raise FailedLoginFailure()
+
+                domain = URL("https://" + url.host) / "login"
+                text = await session.get_text(domain)
+                await asyncio.sleep(5)
+                soup = BeautifulSoup(text, 'html.parser')
+
+                inputs = soup.select('form input')
+                data = {
+                    elem['name']: elem['value']
+                    for elem in inputs
+                    if elem.get('name') and elem.get('value')
+                }
+                data.update({
+                    "login": self.username,
+                    "password": self.password,
+                    "_xfRedirect": str(URL("https://" + url.host))
+                })
+                await session.post_data_no_resp(domain / "login", data=data)
+                await asyncio.sleep(5)
+                text = await session.get_text(domain)
+                if "You are already logged in" not in text:
+                    raise FailedLoginFailure()
+
+                self.logged_in = True
+            except asyncio.exceptions.TimeoutError:
+                attempt += 1
+                continue
 
 
 class XenforoCrawler:
